| kfda | R Documentation |
Train the trainData using KFDA. Basically, we run KFDA using Gaussian kernel. Returns trained KFDA object.
kfda(trainData = data, kernel.name = "rbfdot", kpar.sigma = 0.001, threshold = 1e-05)
trainData |
an optional |
kernel.name |
the kernel function used in training and predicting. This parameter is fixed in the |
kpar.sigma |
hyper-parameter of selected kernel. |
threshold |
the value of the eigenvalue under which principal components are ignored (only valid when features = 0). (default : 1e-05). |
Train the trainData using KFDA. Basically, we run KFDA using Gaussian kernel. Returns trained KFDA object.
Since this function performs KFDA with the appropriate combination of kpca and lda, the following values can show the result of each function.
An object of class kfda.
kpca.train |
An object of class |
lda.rotation.train |
The result of applying LDA, After KPCA is performed on trainData. |
LDs |
A dataframe of linear discriminants of LDA. |
label |
A vector of class label of trainData. |
This package is an early version and will be updated in the future.
Donghwan Kim
ainsuotain@hanmail.net
donhkim9714@korea.ac.kr
dhkim2@bistel.com
Yang, J., Jin, Z., Yang, J. Y., Zhang, D., and Frangi, A. F. (2004) <DOI:10.1016/j.patcog.2003.10.015>. Essence of kernel Fisher discriminant: KPCA plus LDA. Pattern Recognition, 37(10): 2097-2100.
kpca (in package kernlab)
lda (in package MASS)
kfda.predict
# data input
data(iris)
# data separation
idx <- sample(1:dim(iris)[1], round(dim(iris)[1]*0.7))
trainData <- iris[idx, ]
# training KFDA model
kfda.model <- kfda(trainData = trainData, kernel.name = "rbfdot")
# structure of kfda.model
str(kfda.model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.